@@ -6,7 +6,7 @@
 #include <a0/map.h>
 
 #include <pthread.h>
-#include <stdbool.h>
+#include <stddef.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -30,7 +30,7 @@ typedef struct a0_pathglob_s {
   size_t depth;
 } a0_pathglob_t;
 
-a0_err_t a0_pathglob_split(const char* path_pattern, a0_pathglob_t* out);
+a0_err_t a0_pathglob_init(a0_pathglob_t*, const char* path_pattern);
 
 a0_err_t a0_pathglob_match(a0_pathglob_t*, const char* path, bool* out);
 
@@ -45,8 +45,9 @@ typedef struct a0_discovery_s {
   a0_discovery_callback_t _callback;
   pthread_t _thread;
 
-  a0_map_t _watch_map;       // inotify watch descriptor -> absolute path
-  a0_map_t _discovered_map;  // absolute path -> nothing
+  a0_map_t _watch_map;          // inotify watch descriptor -> absolute dir path
+  a0_map_t _reverse_watch_map;  // absolute dir path -> nothing
+  a0_map_t _discovered_map;     // absolute file path -> nothing
   int _epoll_fd;
   int _inotify_fd;
   int _close_fd;
