@@ -17,16 +17,20 @@ struct ReaderSyncZeroCopy : details::CppWrap<a0_reader_sync_zc_t> {
   ReaderSyncZeroCopy() = default;
   ReaderSyncZeroCopy(Arena, ReaderInit, ReaderIter);
 
-  bool has_next();
-  void next(std::function<void(TransportLocked, FlatPacket)>);
+  bool can_read();
+  void read(std::function<void(TransportLocked, FlatPacket)>);
+  void read_blocking(std::function<void(TransportLocked, FlatPacket)>);
+  void read_blocking(TimeMono, std::function<void(TransportLocked, FlatPacket)>);
 };
 
 struct ReaderSync : details::CppWrap<a0_reader_sync_t> {
   ReaderSync() = default;
   ReaderSync(Arena, ReaderInit, ReaderIter);
 
-  bool has_next();
-  Packet next();
+  bool can_read();
+  Packet read();
+  Packet read_blocking();
+  Packet read_blocking(TimeMono);
 };
 
 struct ReaderZeroCopy : details::CppWrap<a0_reader_zc_t> {
@@ -37,8 +41,6 @@ struct ReaderZeroCopy : details::CppWrap<a0_reader_zc_t> {
 struct Reader : details::CppWrap<a0_reader_t> {
   Reader() = default;
   Reader(Arena, ReaderInit, ReaderIter, std::function<void(Packet)>);
-
-  static Packet read_one(Arena, ReaderInit, int flags);
 };
 
 }  // namespace a0
